$title A Model of Traffic Congestion, Housing Prices and Compensating Wage Differentials

$ontext

Thomas F. Rutherford
Jeffrey Dean

Department of Economics
University of Colorado

March, 2003

$offtext

*	Generate a uniform square network:

set	b		Blocks /b1*b6/,
	barc(b,b,b,b)	Arcs defined on blocks;

alias (b,bb,bbb,bbbb);

*	Generate road connections:

barc(b,bb,b+1,bb) = yes;
barc(b,bb,b-1,bb) = yes;
barc(b,bb,b,bb+1) = yes;
barc(b,bb,b,bb-1) = yes;

*	Generate the mapping from blocks to nodes:

set	i		Nodes /n1*n36/,
	bmap(b,b,i)	Network - node assignments,
	a(i,i)		Arcs defined on nodes;

parameter  l(i,*)	Node locations; 

alias (i,j,k);

bmap(b,bb,i) = yes$((ord(b) + card(b)*(ord(bb)-1)) eq ord(i));

*	Generate node-arc incidence matrix:

loop((b,bb,i)$bmap(b,bb,i),
  l(i,"x") = ord(b);
  l(i,"y") = ord(bb);
  loop((bbb,bbbb,j)$bmap(bbb,bbbb,j),
  a(i,j) = yes$barc(b,bb,bbb,bbbb);
));

display a, l;

*	Assign some parameter values:

parameter
	gamma		Disutility of travel time /0.01/,
	theta		Consumption value share /0.66/,
	phi(i)		Labor demand coefficient,
	h0(i)		Housing stock,
	sigma(i)	Labor demand elasticity,
	alpha(i,j)	Travel distance parameter,
	beta(i,j)	Congestion parameter;

phi(i) = 1;
h0(i) = (1-theta);
alpha(i,j) = 0.1;
beta(i,j) = 1;
alpha(i,i) = 0;
beta(i,i) = 0;
sigma(i) = 0.5;

*	Declare the model:

variables	PH(i)		Housing price,
		N(i,j)		Number of households living at i and working at j,
		W(j)		Wage rate,
		T(i,j)		Travel time
		F(i,j)		Flow 
		X(i,j,k)	Multicommodity flow
		U		Equilibrium utility;

positive variables N, X, T;

equations housing, number, balance, employment, time, flow, population;

housing(i)..		PH(i)*h0(i) =E= sum(j, N(i,j) * (1-theta)*W(j));

number(i,j)..		U * PH(i)**(1-theta) =g= exp(-gamma*T(i,j)) * W(j);

balance(i,k)..		sum(a(i,j), X(i,j,k)) =e= N(i,k) + sum(a(j,i), X(j,i,k));

employment(j)..		(N(j,j) + sum(a(i,j), X(i,j,j))) * W(j)**sigma(j) =e= phi(j);

time(i,j,k)$a(i,j)..	T(j,k) + alpha(i,j) + beta(i,j)*power(F(i,j),4) =G= T(i,k);

flow(i,j)$a(i,j)..	F(i,j) =e= sum(k, X(i,j,k));

population..		card(i) =e= sum((i,j), N(i,j));

model spatial / housing.PH, 
		number.N, 
		balance.T, 
		employment.W, 
		time.X, 
		flow.F, 
		population.U/;

*	Insert some lower bounds to avoid bad function calls:

PH.lo(i) = 0.001; W.lo(j) = 0.001;
PH.l(i) = 1;	N.l(i,j) = 0;	N.l(i,i) = 1;
W.l(j) = 1;	T.l(i,j) = alpha(i,j);
F.l(i,j) = 0;	F.fx(i,j)$(not a(i,j)) = 0;
U.l = 1;	T.fx(i,i) = 0;
X.l(i,j,k) = 0;	X.fx(i,j,k)$(not a(i,j)) = 0;
X.fx(i,i,i) = 0;

spatial.iterlim = 0;
solve spatial using mcp;

*	Now appply an assumption about employment -- assume that jobs
*	are more concentrated in the Northeast corner of the city:

phi(j) = 1 + 10 * l(j,"x")*l(j,"y")/(card(j)*card(j));


*	Assume that housing is concentrated in the Northwest:

h0(j) = (1-theta) * (1 + (card(b)-l(j,"x"))*(l(j,"y")-1)/((card(b)-1)*(card(b)-1)));

spatial.iterlim = 10000;
solve spatial using mcp;

alias (b,bb);

*	Generate contour plots on a square grid:

parameter	phival(b,bb)	Values of PHI,
		h0val(b,bb)	Housing stock
		phval(b,bb)	Values of PH (house prices),
		dis(b,bb)	Distance,
		ctim(b,bb)	Average commuting time,
		fval(b,bb)	Traffic inflow 
		cval(b,bb)	Average congestion
		nval(b,bb)	Values of N (number of households),
		wval(b,b)	Values of W
		congest(i,j,*)	Congestion;

congest(i,j,"time")$a(i,j) = alpha(i,j) + beta(i,j)*power(F.l(i,j),4);
congest(i,j,"%")$a(i,j) = 100 * (beta(i,j)*power(F.l(i,j),4)/alpha(i,j))
option congest:1:2:1;
display congest;

loop(bmap(b,bb,j),
	phival(b,bb) = phi(j);
	h0val(b,bb) = h0(j);
	phval(b,bb) = ph.l(j);
	ctim(b,bb)$sum(k,N.l(j,k)) = sum(k, T.l(j,k)*N.l(j,k))/sum(k,N.l(j,k));
	nval(b,bb) = 100 * (sum(k, n.l(j,k))-1);

	fval(b,bb) = sum(k, sum(a(i,j), X.l(i,j,k)));

	cval(b,bb)$sum(k, sum(a(i,j), X.l(i,j,k)) + sum(a(j,i), X.l(j,i,k)))
		= sum(k, sum(a(i,j), X.l(i,j,k)*congest(i,j,"%")) + 
			 sum(a(j,i), X.l(j,i,k)*congest(j,i,"%")) ) /
		sum(k, sum(a(i,j), X.l(i,j,k)) + sum(a(j,i), X.l(j,i,k)));
	wval(b,bb) = w.l(j);
);
display phival, phval, nval, wval, fval, cval;

$setglobal gp_opt1 'set view 0,0,1,1'
$setglobal gp_opt2 'set contour base'
$setglobal gp_opt3 'set cntrparam bspline'
$setglobal gp_opt4 'set cntrparam levels auto 5'
$setglobal gp_opt5 'set noztics'
$setglobal gp_opt6 'set xtics'
$setglobal gp_opt7 'set ytics'
$setglobal gp_opt8 'set nosurface'
$setglobal gp_opt9 'set grid'

*	Generate five contour plots:

$setglobal gp_opt10 "set title 'Employment Demand'"
$batinclude contour phival b bb

$setglobal gp_opt10 "set title 'Housing Stock'"
$batinclude contour h0val b bb


$setglobal gp_opt10 "set title 'Traffic Inflow'"
$batinclude contour fval b bb

$setglobal gp_opt10 "set title 'Average Congestion'"
$batinclude contour cval b bb

$setglobal gp_opt10 "set title 'Commuting Time'"
$batinclude contour ctim b bb

$setglobal gp_opt10 "set title 'Population Density'"
$batinclude contour nval b bb

$setglobal gp_opt10 "set title 'Housing Prices'"
$batinclude contour phval b bb

*	Finally, generate a few "custom-plots":

file kplt /'traffic.plt'/; put kplt; kplt.lw=0;

put 	'set title "Commuting Flows"'/
	'set nokey'/
	'set noborder'/
	'set noyzeroaxis'/
	'set noxtics'/
	'set noytics'/
	'set nolabel'/;
loop(j,
	put 'set label "',j.tl,'" at ',l(j,"x"),',',l(j,"y")/;
);
put	'set xrange [0:',(card(b)+1):0,']'/
	'set yrange [0:',(card(b)+1):0,']'/;

put	"plot '-' with vector"/;

loop((i,j)$(n.l(i,j) gt 0.001),
	put l(i,"x"),l(i,"y"), (l(j,"x")-l(i,"x")), (l(j,"y")-l(i,"y"))/;
);
putclose;

execute 'wgnupl32 traffic.plt -';

*	Expand size of the E-W road along the top of the grid:

beta(i,j)$((l(i,"y") gt 5.5) and (l(j,"y") gt 5.5)) = 0.25;
solve spatial using mcp;

*	Report revised equilibrium:

congest(i,j,"time")$a(i,j) = alpha(i,j) + beta(i,j)*power(F.l(i,j),4);
congest(i,j,"%")$a(i,j) = 100 * (beta(i,j)*power(F.l(i,j),4)/alpha(i,j))
option congest:1:2:1;
display congest;

parameter	deltaph		Change in Housing Prices;

loop(bmap(b,bb,j),
	phival(b,bb) = phi(j);
	h0val(b,bb) = h0(j);
	deltaph(b,bb) = 100 * (ph.l(j)/phval(b,bb)-1);
	phval(b,bb) = ph.l(j);
	ctim(b,bb)$sum(k,N.l(j,k)) = sum(k, T.l(j,k)*N.l(j,k))/sum(k,N.l(j,k));
	nval(b,bb) = 100 * (sum(k, n.l(j,k))-1);

	fval(b,bb) = sum(k, sum(a(i,j), X.l(i,j,k)));

	cval(b,bb)$sum(k, sum(a(i,j), X.l(i,j,k)) + sum(a(j,i), X.l(j,i,k)))
		= sum(k, sum(a(i,j), X.l(i,j,k)*congest(i,j,"%")) + 
			 sum(a(j,i), X.l(j,i,k)*congest(j,i,"%")) ) /
		sum(k, sum(a(i,j), X.l(i,j,k)) + sum(a(j,i), X.l(j,i,k)));
	wval(b,bb) = w.l(j);
);
display phival, phval, nval, wval, fval, cval;

$setglobal gp_opt1 'set view 0,0,1,1'
$setglobal gp_opt2 'set contour base'
$setglobal gp_opt3 'set cntrparam bspline'
$setglobal gp_opt4 'set cntrparam levels auto 5'
$setglobal gp_opt5 'set noztics'
$setglobal gp_opt6 'set xtics'
$setglobal gp_opt7 'set ytics'
$setglobal gp_opt8 'set nosurface'
$setglobal gp_opt9 'set grid'

*	Generate five contour plots:

$setglobal gp_opt10 "set title 'Employment Demand (w/ new road)'"
$batinclude contour phival b bb

$setglobal gp_opt10 "set title 'Housing Stock (w/ new road)'"
$batinclude contour h0val b bb


$setglobal gp_opt10 "set title 'Traffic Inflow (w/ new road)'"
$batinclude contour fval b bb

$setglobal gp_opt10 "set title 'Average Congestion (w/ new road)'"
$batinclude contour cval b bb

$setglobal gp_opt10 "set title 'Commuting Time (w/ new road)'"
$batinclude contour ctim b bb

$setglobal gp_opt10 "set title 'Population Density (w/ new road)'"
$batinclude contour nval b bb

$setglobal gp_opt10 "set title 'Change in Housing Prices'"
$batinclude contour deltaph b bb

*	Finally, generate a few "custom-plots":

put kplt;
put 	'set title "Commuting Flows"'/
	'set nokey'/
	'set noborder'/
	'set noyzeroaxis'/
	'set noxtics'/
	'set noytics'/
	'set nolabel'/;
loop(j,
	put 'set label "',j.tl,'" at ',l(j,"x"),',',l(j,"y")/;
);
put	'set xrange [0:',(card(b)+1):0,']'/
	'set yrange [0:',(card(b)+1):0,']'/;

put	"plot '-' with vector"/;

loop((i,j)$(n.l(i,j) gt 0.001),
	put l(i,"x"),l(i,"y"), (l(j,"x")-l(i,"x")), (l(j,"y")-l(i,"y"))/;
);
putclose;

execute 'wgnupl32 traffic.plt -';
